@@ -1590,6 +1590,22 @@ public:
     inline FrameBuffer& operator/=(FrameBuffer src) { m_tensor /= src.m_tensor; return *this; }
     inline FrameBuffer& operator/=(double src)      { m_tensor /= src; return *this; }
 
+    // デバッグ用同一性検査
+    inline bool EqualityCheck(const FrameBuffer& buf)
+    {
+        return (m_data_type    == buf.m_data_type   ) &&
+               (m_frame_size   == buf.m_frame_size  ) &&
+               (m_frame_stride == buf.m_frame_stride) &&
+               (m_node_size    == buf.m_node_size   ) &&
+               (m_node_shape   == buf.m_node_shape  ) &&
+               (m_tensor       == buf.m_tensor      );
+    }
+
+    inline bool operator==(const FrameBuffer& buf)
+    {
+        return EqualityCheck(buf);
+    }
+    
     bool IsNan(void)
     {
         switch ( GetType() ) {
@@ -1661,11 +1677,37 @@ public:
         return std::sqrt((*this * *this).Sum());
     }
 
-    void Clamp_inplace(double a, double b)
+    FrameBuffer& Clamp_inplace(double a, double b)
     {
         m_tensor.Clamp_inplace(a, b);
+        return *this;
     }
 
+    FrameBuffer Quantize(int bits, double scale=0.0, int offset=0)
+    {
+        FrameBuffer dst(GetFrameSize(), GetShape(), GetType(), IsHostOnly());
+        dst.m_tensor = m_tensor.Quantize(bits, scale, offset);
+        return dst;
+    }
+
+    FrameBuffer& Quantize_inplace(int bits, float scale=0.0f, int offset=0)
+    {
+        m_tensor.Quantize_inplace(bits, scale, offset);
+        return *this;
+    }
+
+    FrameBuffer QuantizeUnsigned(int bits, double scale=0.0, int offset=0)
+    {
+        FrameBuffer dst(GetFrameSize(), GetShape(), GetType(), IsHostOnly());
+        dst.m_tensor = m_tensor.QuantizeUnsigned(bits, scale, offset);
+        return dst;
+    }
+
+    FrameBuffer& QuantizeUnsigned_inplace(int bits, float scale, int offset)
+    {
+        m_tensor.QuantizeUnsigned_inplace(bits, scale, offset);
+        return *this;
+    }
 
     friend  FrameBuffer operator+(FrameBuffer const &src0, FrameBuffer const &src1);
     friend  FrameBuffer operator+(FrameBuffer const &src0, double src1);
