@@ -78,6 +78,36 @@ public:
         auto shape          = t_buf.GetShape();
         auto ch_size        = shape[0];
         auto pix_size       = node_size / ch_size;
+        
+#ifdef BB_WITH_CUDA
+        if ( DataType<T>::type == BB_TYPE_FP32 && pix_size == 1 && y_buf.IsDeviceAvailable() && t_buf.IsDeviceAvailable() && Manager::IsDeviceAvailable() ) {
+            FrameBuffer accuracy_buf(frame_size, {1}, BB_TYPE_INT32);
+            FrameBuffer category_buf(frame_size, {1}, BB_TYPE_INT32);
+
+            {
+                auto y_ptr        = y_buf.LockDeviceMemoryConst();
+                auto t_ptr        = t_buf.LockDeviceMemoryConst();
+                auto accuracy_ptr = accuracy_buf.LockDeviceMemory(true);
+                auto category_ptr = category_buf.LockDeviceMemory(true);
+                bbcu_MetricsCategoricalAccuracy<T>
+                    (
+                        (T   const  *)y_ptr.GetAddr(),
+                        (T   const  *)t_ptr.GetAddr(),
+                        (int        *)accuracy_ptr.GetAddr(),
+                        (int        *)category_ptr.GetAddr(),
+                        (int         )pix_size,
+                        (int         )ch_size,
+                        (int         )frame_size,
+                        (int         )(y_buf.GetFrameStride() / sizeof(float))
+                    );
+            }
+
+            m_accuracy       += (int)accuracy_buf.Sum();
+            m_category_count += (int)category_buf.Sum();
+
+            return;
+        }
+#endif
 
         /*
 #ifdef BB_WITH_CUDA
@@ -109,10 +139,10 @@ public:
  
             for (index_t frame = 0; frame < frame_size; ++frame) {
                 for (index_t pix = 0; pix < pix_size; ++pix) {
-                    T       max_y  = 0;
-                    T       max_t  = 0;
+                    T       max_y  = std::numeric_limits<T>::lowest();
+                    T       max_t  = std::numeric_limits<T>::lowest();
                     bool    valid  = false;
-                    for (index_t ch = 1; ch < ch_size; ++ch) {
+                    for (index_t ch = 0; ch < ch_size; ++ch) {
                         auto node = ch * pix_size + pix;
                         auto    y = y_ptr.Get(frame, node);
                         auto    t = t_ptr.Get(frame, node);
